## CSS - Demos - Icons

<script type="module" src="/web_components/js/css/demos/WebC__CSS__Demo__Icons.mjs"></script>

<webc-container>
    <webc-css-demo-icons        ></webc-css-demo-icons> 
    <webc-css-demo-icons no-css ></webc-css-demo-icons>
    
</webc-container>